﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using MvcWebApp.Models;

namespace MvcWebApp.Controllers
{
    public class ProductsController : Controller
    {
        public ActionResult Categories()
        {
            this.ViewData["Categories"] = Product.All.Select(p => p.Category).Distinct().ToList();

            return this.RenderView("Categories");
        }

        public ActionResult List(string id, int? page)
        {
            int pageNumber = page.HasValue ? page.Value : 1;

            this.ViewData["PageNumber"] = pageNumber;
            this.ViewData["Category"] = id;
            this.ViewData["TotalCount"] = Product.All.Count(p => p.Category == id);
            this.ViewData["Products"] = (from p in Product.All
                                        where p.Category == id
                                        select p).Skip((pageNumber - 1) * 5).Take(5).ToList();

            return this.RenderView("ListingByCategory");
        }

        public ActionResult Edit(int id)
        {
            this.ViewData["Product"] = Product.All.Single(p => p.ProductID == id);
            this.ViewData["Categories"] = Product.All.Select(p => p.Category).Distinct().ToList();

            return this.RenderView("Edit");
        }

        public ActionResult Update(int id)
        {
            Product product = Product.All.Single(p => p.ProductID == id);

            product.Name = this.Request.Form["Name"];
            product.Category = this.Request.Form["Category"];
            product.Price = double.Parse(this.Request.Form["Price"]);

            return this.List(product.Category, 1);
        }
    }
}
